@@ -250,6 +250,8 @@ def __write_function(
             micro_batch_df.alias(micro_batch_df_name), upsert_condition
         ).whenMatchedUpdateAll(match_condition).whenNotMatchedInsertAll().execute()
     else:
+        if insert_mode == "overwrite":
+            truncate_table(spark=spark, db_table=table_name)
         micro_batch_df.write.option("header", "true").option(
             "mergeSchema", "true"
         ).partitionBy(*partition_columns).format("delta").mode(insert_mode).saveAsTable(
@@ -257,6 +259,7 @@ def __write_function(
         )
         spark.sql(f"ALTER TABLE {table_name} OWNER TO `data-platform`")
         print(f"Created table {table_name} and loaded data")
+    print(f"Applied insert mode: {insert_mode}")
 
     return True
 
@@ -393,6 +396,12 @@ def set_owner_to(spark, db_table, owner: str):
 
     return True
 
+def truncate_table(spark, db_table):
+    spark.sql(f"TRUNCATE TABLE {db_table}")
+    print(f"TABLE {db_table} truncated")
+
+    return True
+
 
 def set_tbl_properties(spark, db_table, tbl_properties):
     array_properties = []
@@ -425,6 +434,7 @@ def landing_to_bronze(
     catalog_name=None,
     output_db_name=None,
     tbl_properties=None,
+    upsert_fields: list = None,
 ):
     """
     Perform the ingestion of data into the bronze_layer database
@@ -444,12 +454,14 @@ def landing_to_bronze(
     :param catalog_name: unity catalog name
     :param output_db_name: database where the data will be written
     :param tbl_properties: properties to add to table
+    :param upsert_fields: fields to use when upserting
     :return:
     """
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
     if partition_columns is None:
         partition_columns = list()
+
     if reset_checkpoint:
         reset_autoloader_checkpoint(
             bucket_name=BRONZE_BUCKET,
@@ -506,6 +518,7 @@ def landing_to_bronze(
         spark=spark,
         partition_columns=partition_columns,
         write_options=write_options,
+        upsert_fields=upsert_fields
     )
 
     db_table = f"{db_name}.{dataset_name}"
@@ -540,12 +553,20 @@ def bronze_to_silver(
     profiling=False,
     reset_checkpoint=False,
     catalog_name=None,
-    where=None
+    where=None,
+    tbl_properties=None,
+    sort_fields: list = None,
+    upsert_fields: list = None
+
 ):
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
     if partition_columns is None:
         partition_columns = list()
+    if sort_fields is None:
+        sort_fields = get_table_partitions(
+            spark=spark, db_name=input_db_name, table_name=input_table_name
+        )
     if reset_checkpoint:
         reset_autoloader_checkpoint(
             bucket_name=SILVER_BUCKET,
@@ -571,6 +592,11 @@ def bronze_to_silver(
     input_db_name = f"{catalog_name}.{input_db_name}"
     output_db_name = f"{catalog_name}.{output_db_name}"
 
+    if sort_fields is None:
+        sort_fields = get_table_partitions(
+            spark=spark, db_name=input_db_name, table_name=input_table_name
+        )
+
     df = read_table(spark, db_name=input_db_name, table_name=input_table_name, where=where)
     df = apply_processing_function(
         df=df,
@@ -594,13 +620,25 @@ def bronze_to_silver(
         spark=spark,
         partition_columns=partition_columns,
         write_options=write_options,
+        sort_fields=sort_fields,
+        upsert_fields=upsert_fields
     )
 
+    output_db_table = f"{output_db_name}.{dataset_name}"
+
+    if catalog_name != "hive_metastore":
+        set_owner_to(spark, output_db_table, "data-production")
+
+    if tbl_properties:
+        set_tbl_properties(spark, output_db_table, tbl_properties)
+
     if profiling:
         stream.awaitTermination()
-        df = spark.read.table(f"{output_db_name}.{dataset_name}")
+        df = spark.read.table(output_db_table)
         apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
 
+    return True
+
 
 @__verify_parameters
 def silver_to_gold(
@@ -621,7 +659,8 @@ def silver_to_gold(
     upsert_fields: list = None,
     reset_checkpoint=False,
     catalog_name=None,
-    where=None
+    where=None,
+    tbl_properties=None
 ):
     if spark is None:
         spark = get_spark_session(app_name=dataset_name)
@@ -684,9 +723,17 @@ def silver_to_gold(
         upsert_fields=upsert_fields,
     )
 
+    output_db_table = f"{output_db_name}.{dataset_name}"
+
+    if catalog_name != "hive_metastore":
+        set_owner_to(spark, output_db_table, "data-production")
+
+    if tbl_properties:
+        set_tbl_properties(spark, output_db_table, tbl_properties)
+
     if profiling:
         stream.awaitTermination()
-        df = spark.read.table(f"{output_db_name}.{dataset_name}")
+        df = spark.read.table(output_db_table)
         apply_profiling(df=df, data_pack_name=data_pack_name, dataset_name=dataset_name)
 
 
@@ -712,6 +759,10 @@ def gold_to_kafka(
     checkpoint_location = f"s3://{GOLD_BUCKET}/_databricks_autoloader_checkpoints/kafka/{input_db_name}/{input_table_name}"
     if spark is None:
         spark = get_spark_session(app_name=input_table_name)
+    if sort_fields is None:
+        sort_fields = get_table_partitions(
+            spark=spark, db_name=input_db_name, table_name=input_table_name
+        )
     if reset_checkpoint:
         __delete_checkpoint_location(
             bucket_name=GOLD_BUCKET, checkpoint_location=checkpoint_location
